@@ -46,6 +46,7 @@ static gint     zenity_general_timeout_delay;
 static gchar   *zenity_general_ok_button;
 static gchar   *zenity_general_cancel_button;
 static gboolean zenity_general_modal;
+static gint     zenity_general_attach;
 
 /* Calendar Dialog Options */
 static gboolean zenity_calendar_active;
@@ -99,11 +100,14 @@ static gboolean zenity_progress_no_cancel;
 
 /* Question Dialog Options */
 static gboolean zenity_question_active;
+static gboolean zenity_question_default_cancel;
 
 /* Text Dialog Options */
 static gboolean zenity_text_active;
 static gchar   *zenity_text_font;
 static gchar   *zenity_text_checkbox;
+static gboolean zenity_text_auto_scroll;
+
 #ifdef HAVE_WEBKITGTK
 static gboolean zenity_text_enable_html;
 static gchar   *zenity_text_url;
@@ -137,6 +141,7 @@ static gchar   *zenity_forms_date_format;
 //static gchar   *zenity_forms_hide_column;
 static gchar  **zenity_forms_list_values;
 static gchar  **zenity_forms_column_values;
+static gchar  **zenity_forms_combo_values;
 
 /* Miscelaneus Options */
 static gboolean zenity_misc_about;
@@ -222,6 +227,15 @@ static GOptionEntry general_options[] = {
     N_("Set the modal hint"),
     NULL
   },
+  {
+    "attach",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_INT,
+    &zenity_general_attach,
+    N_("Set the parent window to attach to"),
+    N_("WINDOW")
+  },
   {
     NULL
   }
@@ -786,6 +800,15 @@ static GOptionEntry question_options[] = {
     &zenity_general_dialog_no_markup,
     N_("Do not enable pango markup")
   },
+  {
+    "default-cancel",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_question_default_cancel,
+    N_("Give cancel button focus by default"),
+    NULL
+  },
   { 
     NULL 
   }
@@ -857,6 +880,15 @@ static GOptionEntry text_options[] = {
     N_("URL")
   },
 #endif
+  {
+    "auto-scroll",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_text_auto_scroll,
+    N_("Auto scroll the text to the end. Only when text is captured from stdin"),
+    NULL
+  },
   { 
     NULL 
   }
@@ -1054,6 +1086,24 @@ static GOptionEntry forms_dialog_options[] = {
     N_("List of values for columns"),
     N_("List of values separated by |")
   },
+  {
+    "add-combo",
+    '\0',
+    0,
+    G_OPTION_ARG_CALLBACK,
+    zenity_forms_callback,
+    N_("Add a new combo box in forms dialog"),
+    N_("Combo box field name")
+  },
+  {
+    "combo-values",
+    '\0',
+    0,
+    G_OPTION_ARG_STRING_ARRAY,
+    &zenity_forms_combo_values,
+    N_("List of values for combo box"),
+    N_("List of values separated by |")
+  },
  /* TODO: Implement how to hide specifc column 
   {
     "hide-column",
@@ -1236,6 +1286,8 @@ zenity_option_free (void) {
     g_free (zenity_forms_date_format);
   if (zenity_forms_list_values)
     g_strfreev (zenity_forms_list_values);
+  if (zenity_forms_combo_values)
+    g_strfreev (zenity_forms_combo_values);
   if (zenity_forms_column_values)
     g_strfreev (zenity_forms_column_values);
 //  if (zenity_forms_hide_column)
@@ -1311,6 +1363,8 @@ zenity_forms_callback (const gchar *option_name,
     forms_value->type = ZENITY_FORMS_PASSWORD;
   else if (g_strcmp0 (option_name, "--add-list") == 0)
     forms_value->type = ZENITY_FORMS_LIST;
+  else if (g_strcmp0 (option_name, "--add-combo") == 0)
+    forms_value->type = ZENITY_FORMS_COMBO;
 
   results->forms_data->list = g_slist_append(results->forms_data->list, forms_value);
 
@@ -1350,6 +1404,7 @@ zenity_general_pre_callback (GOptionContext *context,
   zenity_general_dialog_no_markup = FALSE;
   zenity_general_timeout_delay = -1;
   zenity_general_modal = FALSE;
+  zenity_general_attach = 0;
 
   return TRUE;
 }
@@ -1473,6 +1528,7 @@ zenity_question_pre_callback (GOptionContext *context,
 		              GError        **error)
 {
   zenity_question_active = FALSE;
+  zenity_question_default_cancel = FALSE;
 
   return TRUE;
 }
@@ -1486,6 +1542,7 @@ zenity_text_pre_callback (GOptionContext *context,
   zenity_text_active = FALSE;
   zenity_text_font = NULL;
   zenity_text_checkbox = NULL;
+  zenity_text_auto_scroll = FALSE;
 #ifdef HAVE_WEBKITGTK
   zenity_text_enable_html = FALSE;
   zenity_text_url = NULL;
@@ -1588,6 +1645,7 @@ zenity_general_post_callback (GOptionContext *context,
   results->data->ok_label = zenity_general_ok_button;
   results->data->cancel_label = zenity_general_cancel_button;
   results->data->modal = zenity_general_modal;
+  results->data->attach = zenity_general_attach;
   return TRUE;
 }
 
@@ -1878,6 +1936,7 @@ zenity_question_post_callback (GOptionContext *context,
     results->msg_data->mode = ZENITY_MSG_QUESTION;
     results->msg_data->no_wrap = zenity_general_dialog_no_wrap;
     results->msg_data->no_markup = zenity_general_dialog_no_markup;
+    results->msg_data->default_cancel = zenity_question_default_cancel;
   }
 
   return TRUE;
@@ -1897,6 +1956,7 @@ zenity_text_post_callback (GOptionContext *context,
     results->text_data->no_wrap = zenity_general_dialog_no_wrap;
     results->text_data->font = zenity_text_font;
     results->text_data->checkbox = zenity_text_checkbox;
+    results->text_data->auto_scroll = zenity_text_auto_scroll;
 #ifdef HAVE_WEBKITGTK
     results->text_data->html = zenity_text_enable_html;
     results->text_data->url = zenity_text_url;
@@ -2006,6 +2066,14 @@ zenity_forms_post_callback (GOptionContext *context,
     } else
       results->forms_data->column_values = g_slist_append (NULL, "column");
 
+    if (zenity_forms_combo_values) {
+      i = 0;
+      values = zenity_forms_combo_values[0];
+      while (values != NULL) {
+        results->forms_data->combo_values = g_slist_append (results->forms_data->combo_values, values);
+        values = zenity_forms_combo_values[++i];
+      }
+    }
     if (zenity_forms_date_format)
       results->forms_data->date_format = zenity_forms_date_format;
     else
@@ -2023,6 +2091,9 @@ zenity_forms_post_callback (GOptionContext *context,
     if (zenity_forms_column_values)
       zenity_option_error (zenity_option_get_name (forms_dialog_options, &zenity_forms_column_values),
                           ERROR_SUPPORT);
+    if (zenity_forms_combo_values)
+      zenity_option_error (zenity_option_get_name (forms_dialog_options, &zenity_forms_combo_values),
+                          ERROR_SUPPORT);
     if (zenity_forms_show_header)
       zenity_option_error (zenity_option_get_name (forms_dialog_options, &zenity_forms_show_header),
                           ERROR_SUPPORT);
