@@ -33,6 +33,7 @@ typedef struct {
   gint   exit_code;
   gint   timeout_delay;
   gboolean modal;
+  gint   attach;
 } ZenityData;
 
 typedef enum {
@@ -65,6 +66,7 @@ typedef struct {
   MsgMode  mode;
   gboolean no_wrap;
   gboolean no_markup;
+  gboolean default_cancel;
 } ZenityMsgData;
 
 typedef struct {
@@ -108,6 +110,7 @@ typedef struct {
   gchar         *uri;
   gboolean       editable;
   gboolean       no_wrap;
+  gboolean       auto_scroll;
   gchar         *font;
   GtkTextBuffer	*buffer;
   gchar         *checkbox;
@@ -150,6 +153,7 @@ typedef struct {
   GSList *list_widgets;
   GSList *list_values;
   GSList *column_values;
+  GSList *combo_values;
   gchar *dialog_text;
   gchar *separator;
   gchar *date_format;
@@ -161,7 +165,8 @@ typedef enum {
   ZENITY_FORMS_ENTRY,
   ZENITY_FORMS_PASSWORD,
   ZENITY_FORMS_CALENDAR,
-  ZENITY_FORMS_LIST
+  ZENITY_FORMS_LIST,
+  ZENITY_FORMS_COMBO
 } ZenityFormsType;
 
 typedef struct {
